package com.inspect.metadata.montdata.service;

import com.inspect.metadata.montdata.domain.BasedataMontEvnData;

import java.util.List;

public interface IBasedataMontEvnDataService {
    BasedataMontEvnData selectBasedataMontEvnDataByMontEvnDataId(Long dataId);

    List<BasedataMontEvnData> selectBasedataMontEvnDataList(BasedataMontEvnData evnData);

    int insertBasedataMontEvnData(BasedataMontEvnData evnData);

    int updateBasedataMontEvnData(BasedataMontEvnData evnData);

    int deleteBasedataMontEvnDataByMontEvnDataIds(Long[] dataIds);

    int deleteBasedataMontEvnDataByMontEvnDataId(Long dataId);

    List<BasedataMontEvnData> evnList();
}
